% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cellLevelMetrics.R
\name{assingCellsToStructures}
\alias{assingCellsToStructures}
\title{Function to assign spatial points to structures}
\usage{
assingCellsToStructures(
  spe,
  allStructs,
  imageCol,
  uniqueId = "structID",
  nCores = 1
)
}
\arguments{
\item{spe}{SpatialExperiment; An object of class \code{SpatialExperiment} containing spatial point data.}

\item{allStructs}{sf; A simple feature collection (sf object) representing spatial structures. Must contain a column which contains a unique identifier for each structure. Default = \code{structID}.}

\item{imageCol}{character; The column name in \code{spe} and \code{allStructs} that identifies the corresponding image.}

\item{uniqueId}{character; The column name in the simple feature collection for which to compute the assignment.}

\item{nCores}{integer; The number of cores to use for parallel processing (default is 1).}
}
\value{
A vector with structure assignments for each spatial point in \code{spe}. Points that do not overlap with any structure are assigned \code{NA}.
}
\description{
This function assigns each spatial point in a \code{SpatialExperiment} object (\code{spe}) to the first intersecting structure from a given set of spatial structures.
}
\examples{
library("SpatialExperiment")
data("sostaSPE")
allStructs <- reconstructShapeDensitySPE(sostaSPE,
    marks = "cellType", imageCol = "imageName",
    markSelect = "A", bndw = 3.5, thres = 0.045
)
colData(sostaSPE)$structAssign <- assingCellsToStructures(
    sostaSPE,
    allStructs, "imageName"
)
if (require("ggplot2")) {
    cbind(
        colData(sostaSPE[, sostaSPE[["imageName"]] == "image1"]),
        spatialCoords(sostaSPE[, sostaSPE[["imageName"]] == "image1"])
    ) |>
        as.data.frame() |>
        ggplot(aes(x = x, y = y, color = structAssign)) +
        geom_point(size = 0.25) +
        coord_equal()
}
}
